@@ -5,24 +5,21 @@
  *  Copyright (c) 1998-2000 Apple Computer, Inc. All rights reserved.
  *
  *  @APPLE_LICENSE_HEADER_START@
- *  
- *  Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
- *  
- *  This file contains Original Code and/or Modifications of Original Code
- *  as defined in and that are subject to the Apple Public Source License
- *  Version 2.0 (the 'License'). You may not use this file except in
- *  compliance with the License. Please obtain a copy of the License at
- *  http://www.opensource.apple.com/apsl/ and read it before using this
- *  file.
- *  
- *  The Original Code and all software distributed under the License are
- *  distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
- *  EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
+ * 
+ *  The contents of this file constitute Original Code as defined in and
+ *  are subject to the Apple Public Source License Version 1.1 (the
+ *  "License").  You may not use this file except in compliance with the
+ *  License.  Please obtain a copy of the License at
+ *  http://www.apple.com/publicsource and read it before using this file.
+ * 
+ *  This Original Code and all software distributed under the License are
+ *  distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ *  EXPRESS OR IMPLIED, AN APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  *  INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- *  FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- *  Please see the License for the specific language governing rights and
- *  limitations under the License.
- *  
+ *  FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ *  License for the specific language governing rights and limitations
+ *  under the License.
+ * 
  *  @APPLE_LICENSE_HEADER_END@
  *
  *  Hardware independent (relatively) code for the Awacs Controller
@@ -410,9 +407,10 @@ void AppleScreamerAudio::sndHWInitialize(IOService *provider)
 
 void AppleScreamerAudio::checkStatus(bool force) {
 
-    UInt32 newCodecStatus, inSense, extdevices;
-    AudioHardwareDetect *theDetect;
-    OSArray *AudioDetects;
+    UInt32					newCodecStatus, inSense, extdevices;
+	UInt32					numDetects;
+    AudioHardwareDetect *	theDetect;
+    OSArray *				AudioDetects;
 
 	// debugIOLog (3, "+ AppleScreamerAudio::checkStatus");        
     
@@ -429,7 +427,8 @@ void AppleScreamerAudio::checkStatus(bool force) {
 	
 			AudioDetects = getDetectArray();
 			if(AudioDetects) {
-				for(i = 0; i < AudioDetects->getCount(); i++) {
+				numDetects = AudioDetects->getCount();
+				for(i = 0; i < numDetects; i++) {
 					theDetect = OSDynamicCast(AudioHardwareDetect, AudioDetects->getObject(i));
 					if (theDetect) {
 						extdevices |= theDetect->refreshDevices(inSense);
