@@ -17,7 +17,7 @@ EQPrefs         theEQPrefs =
 {
     0x00000001,                         // structVersionNumber
     0x72617720,                         // genreType = 'raw '
-    0x0000000D,                         // eqCount	(update EQPrefsElement array size in AppleTexas2EQPrefs.cpp when updating eqCount!)
+    0x00000012,                         // eqCount	(update EQPrefsElement array size in AppleTexas2EQPrefs.cpp when updating eqCount!)
     0x00000000,                         // nameID
     {                                   // eq
         {                               // ----------     Equalization Set #1     ----------
@@ -26,7 +26,7 @@ EQPrefs         theEQPrefs =
             /*     1.0  */       1,     // drcCompressionRatioDenominator
             /*   -10.8  */  -10750,     // drcThreshold     (X1000)
             /*     2.2  */       4,     // drcMaximumVolume (X2)
-            0x00000000,                 // drcEnable    = ENABLED
+            0x00000001,                 // drcEnable    = ENABLED[3165257]
             0x0000001A,                 // layoutID
             0x00000001,                 // deviceID     = kSndHWInternalSpeaker
             0x00000000,                 // speakerID    = legacy
@@ -395,6 +395,151 @@ EQPrefs         theEQPrefs =
 				{{{ 0x0E, 0x92, 0x4C }, { 0xE6, 0xDC, 0x31 }, { 0x0D, 0x01, 0x97 }, { 0xE6, 0xDC, 0x31 }, { 0x0B, 0x93, 0xE3 }}}, // Right Biquad 4
 				{{{ 0x0F, 0xB9, 0xAC }, { 0xE1, 0xBA, 0xFA }, { 0x0E, 0xE5, 0xFE }, { 0xE1, 0xBA, 0xFA }, { 0x0E, 0x9F, 0xAA }}}, // Right Biquad 5
 				{{{ 0x0D, 0x4B, 0x33 }, { 0x03, 0x63, 0x8F }, { 0x0A, 0xE0, 0xD2 }, { 0x03, 0x63, 0x8F }, { 0x08, 0x2C, 0x06 }}}, // Right Biquad 6
+            }                           // end of filter set
+		},
+		{                               // ----------     Equalization Set #14     ----------
+            /*  44100.0 */   44100,     // filterSampleRate
+            /*     3.0  */       3,     // drcCompressionRatioNumerator
+            /*     1.0  */       1,     // drcCompressionRatioDenominator
+            /*   -12.75 */  -12750,     // drcThreshold     (X1000)
+            /*    -2    */      -4,     // drcMaximumVolume (X2)
+            0x00000001,                 // drcEnable    = ENABLED
+            0x00000026,                 // layoutID     = P72D
+            0x00000001,                 // deviceID     = kSndHWInternalSpeaker
+            0x00000000,                 // speakerID    = Built In
+            0x00000000,                 // reserved     = 0 
+            0x0000000E,                 // filterCount  = 14
+            {                           // filter coefficients in sets of:  b0, b1, b2, a1, a2 and are in 4.20 format
+				{{{ 0x0F, 0x38, 0x87 }, { 0xE1, 0x8E, 0xF1 }, { 0x0F, 0x38, 0x87 }, { 0xE1, 0x98, 0xAA }, { 0x0E, 0x7A, 0xC6 }}}, // Left Biquad 0
+				{{{ 0x06, 0xF5, 0x05 }, { 0x02, 0xAE, 0xAF }, { 0x01, 0x60, 0x98 }, { 0xF7, 0x75, 0x4E }, { 0x03, 0x8F, 0x00 }}}, // Left Biquad 1
+				{{{ 0x0D, 0xB6, 0x8B }, { 0xE5, 0xB0, 0xC3 }, { 0x0D, 0x12, 0x8E }, { 0xE5, 0xB0, 0xC3 }, { 0x0A, 0xC9, 0x1A }}}, // Left Biquad 2
+				{{{ 0x0E, 0xF8, 0x2F }, { 0xE6, 0x79, 0xFB }, { 0x0B, 0xCF, 0xBF }, { 0xE6, 0x79, 0xFB }, { 0x0A, 0xC7, 0xEE }}}, // Left Biquad 3
+				{{{ 0x0F, 0x16, 0x63 }, { 0xE6, 0x47, 0x7B }, { 0x0C, 0xC3, 0x8C }, { 0xE6, 0x47, 0x7B }, { 0x0B, 0xD9, 0xF0 }}}, // Left Biquad 4
+				{{{ 0x0C, 0x69, 0x44 }, { 0x06, 0x59, 0x88 }, { 0x08, 0xD6, 0x56 }, { 0x06, 0x59, 0x88 }, { 0x05, 0x3F, 0x9B }}}, // Left Biquad 5
+				{{{ 0x10, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }}}, // Left Biquad 6
+				{{{ 0x0F, 0x38, 0x87 }, { 0xE1, 0x8E, 0xF1 }, { 0x0F, 0x38, 0x87 }, { 0xE1, 0x98, 0xAA }, { 0x0E, 0x7A, 0xC6 }}}, // Right Biquad 0
+				{{{ 0x06, 0xF5, 0x05 }, { 0x02, 0xAE, 0xAF }, { 0x01, 0x60, 0x98 }, { 0xF7, 0x75, 0x4E }, { 0x03, 0x8F, 0x00 }}}, // Right Biquad 1
+				{{{ 0x0D, 0xB6, 0x8B }, { 0xE5, 0xB0, 0xC3 }, { 0x0D, 0x12, 0x8E }, { 0xE5, 0xB0, 0xC3 }, { 0x0A, 0xC9, 0x1A }}}, // Right Biquad 2
+				{{{ 0x0E, 0xF8, 0x2F }, { 0xE6, 0x79, 0xFB }, { 0x0B, 0xCF, 0xBF }, { 0xE6, 0x79, 0xFB }, { 0x0A, 0xC7, 0xEE }}}, // Right Biquad 3
+				{{{ 0x0F, 0x16, 0x63 }, { 0xE6, 0x47, 0x7B }, { 0x0C, 0xC3, 0x8C }, { 0xE6, 0x47, 0x7B }, { 0x0B, 0xD9, 0xF0 }}}, // Right Biquad 4
+				{{{ 0x0C, 0x69, 0x44 }, { 0x06, 0x59, 0x88 }, { 0x08, 0xD6, 0x56 }, { 0x06, 0x59, 0x88 }, { 0x05, 0x3F, 0x9B }}}, // Right Biquad 5
+				{{{ 0x10, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }, { 0x00, 0x00, 0x00 }}}  // Right Biquad 6
+			}
+ 		},
+		{                               // ----------     Equalization Set #15     ----------
+            /*  44100.0 */   44100,     // filterSampleRate
+            /*     1.0  */       3,     // drcCompressionRatioNumerator
+            /*     1.0  */       1,     // drcCompressionRatioDenominator
+            /*     0.0  */   	 0,     // drcThreshold     (X1000)
+            /*     0.0  */       0,     // drcMaximumVolume (X2)
+            0x00000000,                 // drcEnable    = disabled
+            0x00000027,                 // layoutID     = secrect computer code name
+            0x00000001,                 // deviceID     = kSndHWInternalSpeaker
+            0x00000000,                 // speakerID    = Built In
+            0x00000000,                 // reserved     = 0 
+            0x0000000E,                 // filterCount  = 14
+            {                           // filter coefficients in sets of:  b0, b1, b2, a1, a2 and are in 4.20 format
+				{{{ 0x0F, 0xB2, 0x5C }, { 0xE0, 0x9B, 0x46 }, { 0x0F, 0xB2, 0x5C }, { 0xE0, 0x9C, 0xBE }, { 0x0F, 0x66, 0x32 }}}, // Left Biquad 0
+				{{{ 0x08, 0xA8, 0x11 }, { 0x00, 0xE8, 0x4A }, { 0x01, 0x80, 0x85 }, { 0xF7, 0x84, 0xDC }, { 0x03, 0x8C, 0x05 }}}, // Left Biquad 1
+				{{{ 0x0F, 0xD7, 0x89 }, { 0xE3, 0x8C, 0x1C }, { 0x0F, 0x03, 0x6A }, { 0xE3, 0x8C, 0x1C }, { 0x0E, 0xDA, 0xF3 }}}, // Left Biquad 2
+				{{{ 0x0F, 0xBB, 0x05 }, { 0xE0, 0xF9, 0xAD }, { 0x0F, 0x67, 0x5F }, { 0xE0, 0xF9, 0xAD }, { 0x0F, 0x22, 0x64 }}}, // Left Biquad 3
+				{{{ 0x0F, 0xCB, 0xED }, { 0xE1, 0x16, 0x59 }, { 0x0F, 0x59, 0x4B }, { 0xE1, 0x16, 0x59 }, { 0x0F, 0x25, 0x39 }}}, // Left Biquad 4
+				{{{ 0x0F, 0xB5, 0x30 }, { 0xE2, 0xEE, 0x7E }, { 0x0E, 0xB2, 0x7F }, { 0xE2, 0xEE, 0x7E }, { 0x0E, 0x67, 0xAF }}}, // Left Biquad 5
+				{{{ 0x0E, 0xE5, 0x9D }, { 0x00, 0xF4, 0xC1 }, { 0x0C, 0x33, 0x61 }, { 0x00, 0xF4, 0xC1 }, { 0x0B, 0x18, 0xFE }}}, // Left Biquad 6
+				{{{ 0x0F, 0xB2, 0x5C }, { 0xE0, 0x9B, 0x46 }, { 0x0F, 0xB2, 0x5C }, { 0xE0, 0x9C, 0xBE }, { 0x0F, 0x66, 0x32 }}}, // Right Biquad 0
+				{{{ 0x08, 0xA8, 0x11 }, { 0x00, 0xE8, 0x4A }, { 0x01, 0x80, 0x85 }, { 0xF7, 0x84, 0xDC }, { 0x03, 0x8C, 0x05 }}}, // Right Biquad 1
+				{{{ 0x0F, 0xD7, 0x89 }, { 0xE3, 0x8C, 0x1C }, { 0x0F, 0x03, 0x6A }, { 0xE3, 0x8C, 0x1C }, { 0x0E, 0xDA, 0xF3 }}}, // Right Biquad 2
+				{{{ 0x0F, 0xBB, 0x05 }, { 0xE0, 0xF9, 0xAD }, { 0x0F, 0x67, 0x5F }, { 0xE0, 0xF9, 0xAD }, { 0x0F, 0x22, 0x64 }}}, // Right Biquad 3
+				{{{ 0x0F, 0xCB, 0xED }, { 0xE1, 0x16, 0x59 }, { 0x0F, 0x59, 0x4B }, { 0xE1, 0x16, 0x59 }, { 0x0F, 0x25, 0x39 }}}, // Right Biquad 4
+				{{{ 0x0F, 0xB5, 0x30 }, { 0xE2, 0xEE, 0x7E }, { 0x0E, 0xB2, 0x7F }, { 0xE2, 0xEE, 0x7E }, { 0x0E, 0x67, 0xAF }}}, // Right Biquad 5
+				{{{ 0x0E, 0xE5, 0x9D }, { 0x00, 0xF4, 0xC1 }, { 0x0C, 0x33, 0x61 }, { 0x00, 0xF4, 0xC1 }, { 0x0B, 0x18, 0xFE }}} // Right Biquad 6
+			}
+		},
+		{                               // ----------     Equalization Set #16     ----------
+            /*  44100.0 */   44100,     // filterSampleRate
+            /*     3.0  */       3,     // drcCompressionRatioNumerator
+            /*     1.0  */       1,     // drcCompressionRatioDenominator
+            /*    -9.0  */   -9000,     // drcThreshold     (X1000)
+            /*    -0.0  */       0,     // drcMaximumVolume (X2)
+            0x00000001,                 // drcEnable    = ENABLED
+            0x00000028,                 // layoutID     = (as appropriate)
+            0x00000001,                 // deviceID     = internal speaker
+            0x00000000,                 // speakerID    = (as appropriate)
+            0x00000000,                 // reserved     = 0 
+            0x0000000E,                 // filterCount  = 14
+            {                           // filter coefficients in sets of:  b0, b1, b2, a1, a2 and are in 4.20 format
+				{{{ 0x0F, 0x9D, 0x90 }, { 0xE0, 0xC4, 0xDF }, { 0x0F, 0x9D, 0x90 }, { 0xE0, 0xC7, 0x3C }, { 0x0F, 0x3D, 0x7E }}},
+				{{{ 0x10, 0x52, 0x4F }, { 0xE2, 0x03, 0x59 }, { 0x0D, 0xDD, 0xA6 }, { 0xE1, 0xF8, 0x58 }, { 0x0E, 0x24, 0xF4 }}},
+				{{{ 0x0F, 0xDC, 0x22 }, { 0xF9, 0xD7, 0x33 }, { 0x0E, 0x35, 0x83 }, { 0xF9, 0xD7, 0x33 }, { 0x0E, 0x11, 0xA6 }}},
+				{{{ 0x0F, 0xB6, 0xEE }, { 0xE0, 0xF2, 0xD6 }, { 0x0F, 0x6E, 0x2D }, { 0xE0, 0xF2, 0xD6 }, { 0x0F, 0x25, 0x1B }}},
+				{{{ 0x0F, 0x90, 0x6B }, { 0xEF, 0x92, 0xF7 }, { 0x0D, 0x52, 0x87 }, { 0xEF, 0x92, 0xF7 }, { 0x0C, 0xE2, 0xF2 }}},
+				{{{ 0x0F, 0xDF, 0xC6 }, { 0xE0, 0x97, 0xE6 }, { 0x0F, 0xB3, 0x55 }, { 0xE0, 0x97, 0xE6 }, { 0x0F, 0x93, 0x1B }}},
+				{{{ 0x0F, 0xCE, 0x04 }, { 0xE2, 0xBB, 0x2D }, { 0x0E, 0xBA, 0x16 }, { 0xE2, 0xBB, 0x2D }, { 0x0E, 0x88, 0x1A }}},
+				{{{ 0x0F, 0x9D, 0x90 }, { 0xE0, 0xC4, 0xDF }, { 0x0F, 0x9D, 0x90 }, { 0xE0, 0xC7, 0x3C }, { 0x0F, 0x3D, 0x7E }}},
+				{{{ 0x10, 0x52, 0x4F }, { 0xE2, 0x03, 0x59 }, { 0x0D, 0xDD, 0xA6 }, { 0xE1, 0xF8, 0x58 }, { 0x0E, 0x24, 0xF4 }}},
+				{{{ 0x0F, 0xDC, 0x22 }, { 0xF9, 0xD7, 0x33 }, { 0x0E, 0x35, 0x83 }, { 0xF9, 0xD7, 0x33 }, { 0x0E, 0x11, 0xA6 }}},
+				{{{ 0x0F, 0xB6, 0xEE }, { 0xE0, 0xF2, 0xD6 }, { 0x0F, 0x6E, 0x2D }, { 0xE0, 0xF2, 0xD6 }, { 0x0F, 0x25, 0x1B }}},
+				{{{ 0x0F, 0x90, 0x6B }, { 0xEF, 0x92, 0xF7 }, { 0x0D, 0x52, 0x87 }, { 0xEF, 0x92, 0xF7 }, { 0x0C, 0xE2, 0xF2 }}},
+				{{{ 0x0F, 0xDF, 0xC6 }, { 0xE0, 0x97, 0xE6 }, { 0x0F, 0xB3, 0x55 }, { 0xE0, 0x97, 0xE6 }, { 0x0F, 0x93, 0x1B }}},
+				{{{ 0x0F, 0xCE, 0x04 }, { 0xE2, 0xBB, 0x2D }, { 0x0E, 0xBA, 0x16 }, { 0xE2, 0xBB, 0x2D }, { 0x0E, 0x88, 0x1A }}},
+            }                           // end of filter set
+		},
+		{                               // ----------     Equalization Set #17     ----------
+            /*  44100.0 */   44100,     // filterSampleRate
+            /*     1.6  */       3,     // drcCompressionRatioNumerator
+            /*     1.6  */       1,     // drcCompressionRatioDenominator
+            /*   -10.5  */  -10500,     // drcThreshold     (X1000)
+            /*    +3.0  */       6,     // drcMaximumVolume (X2)
+            0x00000001,                 // drcEnable    = ENABLED
+            0x00000023,                 // layoutID     =
+            0x00000001,                 // deviceID     = kSndHWInternalSpeaker
+            0x00000000,                 // speakerID    = Built In
+            0x00000000,                 // reserved     = 0 
+            0x0000000E,                 // filterCount  = 14
+            {                           // filter coefficients in sets of:  b0, b1, b2, a1, a2 and are in 4.20 format
+				{{{ 0x0F, 0x3B, 0xB8 }, { 0xE1, 0x88, 0x8E }, { 0x0F, 0x3B, 0xA2 }, { 0xE1, 0x8D, 0x5F }, { 0x0E, 0x7C, 0x43 }}}, // Left Biquad 0
+				{{{ 0x0F, 0xBF, 0xD1 }, { 0xE1, 0x80, 0x0A }, { 0x0F, 0x16, 0x85 }, { 0xE1, 0x80, 0x0A }, { 0x0E, 0xD6, 0x57 }}}, // Left Biquad 1
+				{{{ 0x0F, 0xD3, 0xAC }, { 0xE0, 0xF3, 0xF5 }, { 0x0F, 0x46, 0x2F }, { 0xE0, 0xF3, 0xF5 }, { 0x0F, 0x19, 0xDC }}}, // Left Biquad 2
+				{{{ 0x0E, 0xF5, 0x3C }, { 0xE4, 0xB6, 0x6E }, { 0x0D, 0xA6, 0xAB }, { 0xE4, 0xB6, 0x6E }, { 0x0C, 0x9B, 0xE7 }}}, // Left Biquad 3
+				{{{ 0x0F, 0x38, 0xF4 }, { 0xE2, 0x06, 0xB6 }, { 0x0E, 0xE5, 0x5A }, { 0xE2, 0x06, 0xB6 }, { 0x0E, 0x1E, 0x4F }}}, // Left Biquad 4
+				{{{ 0x0F, 0x79, 0x9A }, { 0xE6, 0x0A, 0x77 }, { 0x0D, 0xF4, 0xAC }, { 0xE6, 0x0A, 0x77 }, { 0x0D, 0x6E, 0x47 }}}, // Left Biquad 5
+				{{{ 0x05, 0x9A, 0x40 }, { 0x00, 0xA9, 0xB1 }, { 0x03, 0xC3, 0x6C }, { 0x00, 0xA9, 0xB1 }, { 0xF9, 0x5D, 0xAC }}}, // Left Biquad 6
+				{{{ 0x0F, 0x3B, 0xB8 }, { 0xE1, 0x88, 0x8E }, { 0x0F, 0x3B, 0xA2 }, { 0xE1, 0x8D, 0x5F }, { 0x0E, 0x7C, 0x43 }}}, // Right Biquad 0
+				{{{ 0x0F, 0xBF, 0xD1 }, { 0xE1, 0x80, 0x0A }, { 0x0F, 0x16, 0x85 }, { 0xE1, 0x80, 0x0A }, { 0x0E, 0xD6, 0x57 }}}, // Right Biquad 1
+				{{{ 0x0F, 0xD3, 0xAC }, { 0xE0, 0xF3, 0xF5 }, { 0x0F, 0x46, 0x2F }, { 0xE0, 0xF3, 0xF5 }, { 0x0F, 0x19, 0xDC }}}, // Right Biquad 2
+				{{{ 0x0E, 0xF5, 0x3C }, { 0xE4, 0xB6, 0x6E }, { 0x0D, 0xA6, 0xAB }, { 0xE4, 0xB6, 0x6E }, { 0x0C, 0x9B, 0xE7 }}}, // Right Biquad 3
+				{{{ 0x0F, 0x38, 0xF4 }, { 0xE2, 0x06, 0xB6 }, { 0x0E, 0xE5, 0x5A }, { 0xE2, 0x06, 0xB6 }, { 0x0E, 0x1E, 0x4F }}}, // Right Biquad 4
+				{{{ 0x0F, 0x79, 0x9A }, { 0xE6, 0x0A, 0x77 }, { 0x0D, 0xF4, 0xAC }, { 0xE6, 0x0A, 0x77 }, { 0x0D, 0x6E, 0x47 }}}, // Right Biquad 5
+				{{{ 0x05, 0x9A, 0x40 }, { 0x00, 0xA9, 0xB1 }, { 0x03, 0xC3, 0x6C }, { 0x00, 0xA9, 0xB1 }, { 0xF9, 0x5D, 0xAC }}} // Right Biquad 6
+			}
+		},
+		{                               // ----------     Equalization Set #18     ----------
+            /*  44100.0 */   44100,     // filterSampleRate
+            /*     3.0  */       3,     // drcCompressionRatioNumerator
+            /*     1.0  */       1,     // drcCompressionRatioDenominator
+            /*   -12.0  */  -12000,     // drcThreshold     (X1000)
+            /*    -1.0  */      -2,     // drcMaximumVolume (X2)
+            0x00000001,                 // drcEnable    = ENABLED
+            0x0000002C,                 // layoutID     = (as appropriate)
+            0x00000001,                 // deviceID     = internal speaker
+            0x00000000,                 // speakerID    = (as appropriate)
+            0x00000000,                 // reserved     = 0 
+            0x0000000E,                 // filterCount  = 14
+            {                           // filter coefficients in sets of:  b0, b1, b2, a1, a2 and are in 4.20 format
+				{{{ 0x0F, 0x12, 0x16 }, { 0xE1, 0xDB, 0xD3 }, { 0x0F, 0x12, 0x16 }, { 0xE1, 0xE7, 0xF5 }, { 0x0E, 0x30, 0x4D }}}, // Left Biquad 0
+				{{{ 0x06, 0x80, 0x26 }, { 0x02, 0xC8, 0xF9 }, { 0x01, 0x53, 0xD5 }, { 0xF6, 0xF4, 0x6D }, { 0x03, 0xA8, 0x87 }}}, // Left Biquad 1
+				{{{ 0x0F, 0xAA, 0xEB }, { 0xEB, 0x46, 0x7D }, { 0x0D, 0xB8, 0xF2 }, { 0xEB, 0x46, 0x7D }, { 0x0D, 0x63, 0xDD }}}, // Left Biquad 2
+				{{{ 0x0F, 0x3D, 0x17 }, { 0xE4, 0xFB, 0x96 }, { 0x0C, 0x84, 0x78 }, { 0xE4, 0xFB, 0x96 }, { 0x0B, 0xC1, 0x90 }}}, // Left Biquad 3
+				{{{ 0x0D, 0xEB, 0x68 }, { 0xE5, 0x06, 0xDD }, { 0x0D, 0x76, 0xD9 }, { 0xE5, 0x06, 0xDD }, { 0x0B, 0x62, 0x42 }}}, // Left Biquad 4
+				{{{ 0x0B, 0x13, 0xD3 }, { 0x03, 0x0E, 0xB4 }, { 0x07, 0x75, 0x7A }, { 0x03, 0x0E, 0xB4 }, { 0x02, 0x89, 0x4E }}}, // Left Biquad 5
+				{{{ 0x0F, 0x5A, 0xAE }, { 0xE5, 0x18, 0x5B }, { 0x0D, 0xD3, 0x23 }, { 0xE5, 0x18, 0x5B }, { 0x0D, 0x2D, 0xD1 }}}, // Left Biquad 6
+				{{{ 0x0F, 0x12, 0x16 }, { 0xE1, 0xDB, 0xD3 }, { 0x0F, 0x12, 0x16 }, { 0xE1, 0xE7, 0xF5 }, { 0x0E, 0x30, 0x4D }}}, // Right Biquad 0
+				{{{ 0x06, 0x80, 0x26 }, { 0x02, 0xC8, 0xF9 }, { 0x01, 0x53, 0xD5 }, { 0xF6, 0xF4, 0x6D }, { 0x03, 0xA8, 0x87 }}}, // Right Biquad 1
+				{{{ 0x0F, 0xAA, 0xEB }, { 0xEB, 0x46, 0x7D }, { 0x0D, 0xB8, 0xF2 }, { 0xEB, 0x46, 0x7D }, { 0x0D, 0x63, 0xDD }}}, // Right Biquad 2
+				{{{ 0x0F, 0x3D, 0x17 }, { 0xE4, 0xFB, 0x96 }, { 0x0C, 0x84, 0x78 }, { 0xE4, 0xFB, 0x96 }, { 0x0B, 0xC1, 0x90 }}}, // Right Biquad 3
+				{{{ 0x0D, 0xEB, 0x68 }, { 0xE5, 0x06, 0xDD }, { 0x0D, 0x76, 0xD9 }, { 0xE5, 0x06, 0xDD }, { 0x0B, 0x62, 0x42 }}}, // Right Biquad 4
+				{{{ 0x0B, 0x13, 0xD3 }, { 0x03, 0x0E, 0xB4 }, { 0x07, 0x75, 0x7A }, { 0x03, 0x0E, 0xB4 }, { 0x02, 0x89, 0x4E }}}, // Right Biquad 5
+				{{{ 0x0F, 0x5A, 0xAE }, { 0xE5, 0x18, 0x5B }, { 0x0D, 0xD3, 0x23 }, { 0xE5, 0x18, 0x5B }, { 0x0D, 0x2D, 0xD1 }}} // Right Biquad 6
             }                           // end of filter set
 		}
     }
