@@ -5,24 +5,21 @@
  *  Copyright (c) 1998-2000 Apple Computer, Inc. All rights reserved.
  *
  *  @APPLE_LICENSE_HEADER_START@
- *  
- *  Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
- *  
- *  This file contains Original Code and/or Modifications of Original Code
- *  as defined in and that are subject to the Apple Public Source License
- *  Version 2.0 (the 'License'). You may not use this file except in
- *  compliance with the License. Please obtain a copy of the License at
- *  http://www.opensource.apple.com/apsl/ and read it before using this
- *  file.
- *  
- *  The Original Code and all software distributed under the License are
- *  distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * 
+ *  The contents of this file constitute Original Code as defined in and
+ *  are subject to the Apple Public Source License Version 1.1 (the
+ *  "License").  You may not use this file except in compliance with the
+ *  License.  Please obtain a copy of the License at
+ *  http://www.apple.com/publicsource and read it before using this file.
+ * 
+ *  This Original Code and all software distributed under the License are
+ *  distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  *  EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  *  INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- *  FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- *  Please see the License for the specific language governing rights and
- *  limitations under the License.
- *  
+ *  FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ *  License for the specific language governing rights and limitations
+ *  under the License.
+ * 
  *  @APPLE_LICENSE_HEADER_END@
  *
  *  Hardware independent (relatively) code for the Texas Insruments TAS3004 Codec
@@ -475,22 +472,31 @@ UInt32 AppleTAS3004Audio::getMaximumVolume () {
 	return maxVolume;
 }
 
+// --------------------------------------------------------------------------
 UInt32 AppleTAS3004Audio::getMaximumdBGain (void) {
 	return kTAS3004_Plus_12dB;
 }
 
+// --------------------------------------------------------------------------
 UInt32 AppleTAS3004Audio::getMinimumdBGain (void) {
 	return kTAS3004_Minus_12dB;
 }
 
+// --------------------------------------------------------------------------
 UInt32 AppleTAS3004Audio::getMaximumGain (void) {
 	return kTAS3004_MaxGainSteps;
 }
 
+// --------------------------------------------------------------------------
 UInt32 AppleTAS3004Audio::getMinimumGain (void) {
 	return 0;
 }
 
+// --------------------------------------------------------------------------
+UInt32 AppleTAS3004Audio::getDefaultInputGain (void) {
+	return ( getMinimumGain() + (( getMaximumGain() - getMinimumGain() ) / 2 ) );
+}
+
 // --------------------------------------------------------------------------
 bool AppleTAS3004Audio::setCodecVolume(UInt32 leftVolume, UInt32 rightVolume)
 {
@@ -1209,6 +1215,17 @@ Exit:
 	return hasInput;
 }
 
+
+//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+void AppleTAS3004Audio::setDRCProcessing (void * inDRCStructure, Boolean inRealtime) {
+	return;
+}
+
+//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+void AppleTAS3004Audio::setEQProcessing (void * inEQStructure, Boolean inRealtime) {
+	return;
+}
+
 IOReturn AppleTAS3004Audio::setBiquadCoefficients ( void * biquadCoefficients )
 {
 	IOReturn		err;
@@ -1227,6 +1244,10 @@ IOReturn AppleTAS3004Audio::setBiquadCoefficients ( void * biquadCoefficients )
 	return totalErr;
 }
 
+IOReturn AppleTAS3004Audio::BuildCustomEQCoefficients ( void * inEQStructure ) 
+{
+	return kIOReturnSuccess;
+}
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 //	This routine will only restore unity gain all pass coefficients to the
 //	biquad registers.  All other coefficients to be passed through exported
@@ -1286,7 +1307,9 @@ void AppleTAS3004Audio::disableProcessing ( Boolean inRealtime ) {
 			CODEC_WriteRegister( index, &data[3], kUPDATE_ALL );
 			CODEC_WriteRegister( index + ( kTAS3004RightBiquad0CtrlReg - kTAS3004LeftBiquad0CtrlReg ), &data[3], kUPDATE_ALL );
 		}
-			
+	
+		setDRCProcessing ( NULL, FALSE );
+		
 		CODEC_WriteRegister( kTAS3004LeftBiquad6CtrlReg, &data[3], kUPDATE_ALL );
 		CODEC_WriteRegister( kTAS3004RightBiquad6CtrlReg, &data[0], kUPDATE_ALL );
 	
